@@ -9,8 +9,8 @@ module ActiveJob
   module VERSION
     MAJOR = 7
     MINOR = 0
-    TINY  = 8
-    PRE   = "1"
+    TINY  = 10
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
